@@ -147,22 +147,6 @@ EXTERN_C FILE *fdopen (int fildes, const char *mode); /* GCC 3.0 SUXX */
 
 int CGIFFF _GifError = 0;
 
-#if 0 /**** pts ****/
-#ifdef SYSV
-static char *VersionStr =
-        "Gif library module,\t\tGershon Elber\n\
-	(C) Copyright 1989 Gershon Elber, Non commercial use only.\n";
-#else
-static char *VersionStr =
-	PROGRAM_NAME
-	"	IBMPC "
-	GIF_LIB_VERSION
-	"	Gershon Elber,	"
-	__DATE__ ",   " __TIME__ "\n"
-	"(C) Copyright 1989 Gershon Elber, Non commercial use only.\n";
-#endif /* SYSV */
-#endif
-
 /*****************************************************************************
 * Return the last GIF error (0 if none) and reset the error.		     *
 *****************************************************************************/
@@ -177,9 +161,9 @@ int CGIFFF GifLastError(void)
 
 /**** pts ****/
 /** May return NULL. */
-char *CGIFFF GetGifError(void)
+PTS_const char *CGIFFF GetGifError(void)
 {
-    char *Err;
+    PTS_const char *Err;
 
     switch(_GifError) {
 #if 0 /**** pts ****/
@@ -265,7 +249,7 @@ char *CGIFFF GetGifError(void)
 *****************************************************************************/
 void CGIFFF PrintGifError(void)
 {
-    char *Err=GetGifError();
+    PTS_const char *Err=GetGifError();
     if (Err != NULL)
 	fprintf(stderr, "\nGIF-LIB error: %s.\n", Err);
     else
@@ -646,22 +630,6 @@ typedef struct GifFilePrivateType {
     unsigned int Prefix[LZ_MAX_CODE+1];
 } GifFilePrivateType;
 
-#if 0 /**** pts ****/
-#ifdef SYSV
-static char *VersionStr =
-        "Gif library module,\t\tGershon Elber\n\
-	(C) Copyright 1989 Gershon Elber, Non commercial use only.\n";
-#else
-static char *VersionStr =
-	PROGRAM_NAME
-	"	IBMPC "
-	GIF_LIB_VERSION
-	"	Gershon Elber,	"
-	__DATE__ ",   " __TIME__ "\n"
-	"(C) Copyright 1989 Gershon Elber, Non commercial use only.\n";
-#endif /* SYSV */
-#endif
-
 /* extern int _GifError; */
 
 static int DGifGetWord(FILE *File, int *Word);
@@ -1198,7 +1166,8 @@ static int DGifSetupDecompress(CGIFFF GifFileType *GifFile)
     unsigned int *Prefix;
     GifFilePrivateType *Private = (GifFilePrivateType *) GifFile->Private;
 
-    fread(&CodeSize, 1, 1, Private->File);    /* Read Code size from file. */
+    if (fread(&CodeSize, 1, 1, Private->File) != 1)  /* Read Code size from file. */
+      return GIF_ERROR;
     BitsPerPixel = CodeSize;
 
     Private->Buf[0] = 0;			      /* Input Buffer empty. */
