@@ -391,7 +391,7 @@ void Rule::OutputRule::fromDict(MiniPS::VALUE dict_) {
     "TransferCPL",     MiniPS::S_PINTEGER,MiniPS::Qinteger(78),  &TransferCPL,
     "DCT",             MiniPS::T_DICT,    MiniPS::Qnull,         &DCT,
     "Scale",           MiniPS::S_SENUM,   y_Scale,               &Scale,
-    "ImageDPI",        MiniPS::S_PNUMBER, MiniPS::Qinteger(72),  &cacheHints.ImageDPI,
+    "ImageDPI",        MiniPS::S_NUMBER,  MiniPS::Qinteger(72),  &cacheHints.ImageDPI,
     "TopMargin",       MiniPS::S_NUMBER,  MiniPS::Qinteger(0),   &cacheHints.TopMargin,
     "BottomMargin",    MiniPS::S_NUMBER,  MiniPS::Qinteger(0),   &cacheHints.BottomMargin,
     "LeftMargin",      MiniPS::S_NUMBER,  MiniPS::Qinteger(0),   &cacheHints.LeftMargin,
@@ -544,7 +544,8 @@ void Rule::OutputRule::appendDecoderSpec(GenBuffer::Writable &out) const {
 
 bool Rule::OutputRule::hasPredictorSpec() const {
   return cache.Compression==cache.CO_Fax
-      || (cache.Compression==cache.CO_ZIP || cache.Compression==cache.CO_LZW) && cache.Predictor!=cache.PR_None;
+    || ((cache.Compression==cache.CO_ZIP || cache.Compression==cache.CO_LZW) &&
+        cache.Predictor!=cache.PR_None);
 }
 
 void Rule::OutputRule::appendPredictorSpec(GenBuffer::Writable &out) const {
@@ -957,8 +958,9 @@ void Rule::writeTTE(
      case 's': /* scaling to a full PostScript page or translation for PDF and EPS */
       nzp=!(MiniPS::isZero(or_->cacheHints.LowerMargin)
          && MiniPS::isZero(or_->cacheHints.TopMargin));
-      scp=!MiniPS::isEq(or_->cacheHints.ImageDPI, 72);
-      
+      scp=!MiniPS::isEq(or_->cacheHints.ImageDPI, 72) &&
+          !MiniPS::isEq(or_->cacheHints.ImageDPI, -72);
+
       if (or_->cache.isPDF()) {
         SimBuffer::B scf;
         if (scp) MiniPS::dumpScale(scf, or_->cacheHints.ImageDPI);
